diff --git a/docs/install-in-windows.txt b/docs/install-in-windows.txt
index d9b27768..96a2524e 100644
--- a/docs/install-in-windows.txt
+++ b/docs/install-in-windows.txt
@@ -24,7 +24,7 @@ Once finished it shold confirm "service started successfully"
1b. MySQL database and user setup
Now open a shell (aka command prompt aka DOS window):
-Click Start, then Run. In the opening window type "cmd" (without the inverted commas) and then click OK. A windows with a black background should open.
+Click Start, then Run. In the opening window type "cmd" (without the inverted commas) and then click OK. A window with a black background should open.
Type (replacing yourPassword with the root password for MySQL you specified during installation):
mysql --user=root --password=yourPassword
diff --git a/docs/tabledesign.html b/docs/tabledesign.html
index 8d9a31a9..0f22247c 100644
--- a/docs/tabledesign.html
+++ b/docs/tabledesign.html
@@ -547,6 +547,11 @@ The program itself is licensed under AGPLv3, see agpl-3.0.txt
position |
char(1) |
Position for which this row applies. In this table this can be B(BB), S(SB), D(Dealer/Button), C(Cutoff), M(Middle - the 3 before cutoff) or E (Early - the 3 before Middle) |
+
+ tourneysGametypeId |
+ smallint |
+ References TourneysGametypes.id |
+
@@ -617,9 +622,9 @@ The program itself is licensed under AGPLv3, see agpl-3.0.txt
|
- tourneyGametypeId |
+ tourneysGametypeId |
smallint |
- References TourneyGametypes.id |
+ References TourneysGametypes.id |
siteTourneyNo |
diff --git a/pyfpdb/fpdb.py b/pyfpdb/fpdb.py
index b3fef587..6946d2cc 100755
--- a/pyfpdb/fpdb.py
+++ b/pyfpdb/fpdb.py
@@ -363,7 +363,7 @@ This program is licensed under the AGPL3, see docs"""+os.sep+"agpl-3.0.txt")
self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
self.window.connect("delete_event", self.delete_event)
self.window.connect("destroy", self.destroy)
- self.window.set_title("Free Poker DB - version: alpha1+, git39")
+ self.window.set_title("Free Poker DB - version: alpha1+, git40")
self.window.set_border_width(1)
self.window.set_size_request(1020,400)
self.window.set_resizable(True)
diff --git a/pyfpdb/import_threaded.py b/pyfpdb/import_threaded.py
old mode 100755
new mode 100644
diff --git a/pyfpdb/table_viewer.py b/pyfpdb/table_viewer.py
old mode 100755
new mode 100644
index e4686a17..6afae5d9
--- a/pyfpdb/table_viewer.py
+++ b/pyfpdb/table_viewer.py
@@ -59,7 +59,7 @@ class table_viewer (threading.Thread):
arr=[]
#first prepare the header row
if (self.category=="holdem" or self.category=="omahahi" or self.category=="omahahilo"):
- tmp=("Name", "Hands", "VPIP", "PFR", "PF3B4B", "ST")
+ tmp=("Name", "HDs", "VPIP", "PFR", "PF3B4B", "ST")
if self.settings['tv-combinedStealFold']:
tmp+=("FSB", )
diff --git a/pyfpdb/fpdb_db.py b/pyfpdb/fpdb_db.py
old mode 100755
new mode 100644
index f83c9dbb..688c6673
--- a/pyfpdb/fpdb_db.py
+++ b/pyfpdb/fpdb_db.py
@@ -47,7 +47,7 @@ class fpdb_db:
try:
self.cursor.execute("SELECT * FROM Settings")
settings=self.cursor.fetchone()
- if settings[0]!=39:
+ if settings[0]!=40:
print "outdated database version - please recreate tables"
except:# _mysql_exceptions.ProgrammingError:
print "failed to read settings table - please recreate tables"
@@ -119,11 +119,11 @@ class fpdb_db:
self.cursor.execute("DROP TABLE IF EXISTS HandsActions;")
self.cursor.execute("DROP TABLE IF EXISTS HandsPlayers;")
self.cursor.execute("DROP TABLE IF EXISTS Hands;")
- self.cursor.execute("DROP TABLE IF EXISTS TourneysGametypes;")
self.cursor.execute("DROP TABLE IF EXISTS TourneysPlayers;")
self.cursor.execute("DROP TABLE IF EXISTS Tourneys;")
self.cursor.execute("DROP TABLE IF EXISTS Players;")
self.cursor.execute("DROP TABLE IF EXISTS Gametypes;")
+ self.cursor.execute("DROP TABLE IF EXISTS TourneysGametypes;")
self.cursor.execute("DROP TABLE IF EXISTS Sites;")
self.db.commit()
@@ -206,7 +206,7 @@ class fpdb_db:
card5Suit char(1))""")
self.create_table("""TourneysGametypes (
id INT UNSIGNED UNIQUE AUTO_INCREMENT, PRIMARY KEY (id),
siteId SMALLINT UNSIGNED, FOREIGN KEY (siteId) REFERENCES Sites(id),
buyin INT,
fee INT,
@@ -313,9 +313,10 @@ class fpdb_db:
thirdBarrelChance INT,
thirdBarrelDone INT,
- position CHAR(1))""")
+ position CHAR(1),
+ tourneysGametypeId SMALLINT UNSIGNED, FOREIGN KEY (tourneysGametypeId) REFERENCES TourneysGametypes(id))""")
- self.cursor.execute("INSERT INTO Settings VALUES (39);")
+ self.cursor.execute("INSERT INTO Settings VALUES (40);")
self.cursor.execute("INSERT INTO Sites VALUES (DEFAULT, \"Full Tilt Poker\", 'USD');")
self.cursor.execute("INSERT INTO Sites VALUES (DEFAULT, \"PokerStars\", 'USD');")
self.db.commit()
@@ -206,7 +206,7 @@ class fpdb_db:
card5Suit char(1))""")
self.create_table("""TourneysGametypes (
- id INT UNSIGNED UNIQUE AUTO_INCREMENT, PRIMARY KEY (id),
+ id SMALLINT UNSIGNED UNIQUE AUTO_INCREMENT, PRIMARY KEY (id),
siteId SMALLINT UNSIGNED, FOREIGN KEY (siteId) REFERENCES Sites(id),
buyin INT,